class Person {
    protected String firstName;
    protected String lastName;
    Person() {}
    Person(String fName, String lName) {
        firstName = fName;
        lastName = lName;
    }
}


/**
  * The <tt>Employee</tt> class is used to represent
  * employees of our company. It augments the <tt>Person</tt>
  * class with information about an employee's salary and
  * job title.<p>
  * This class was written by:
  * <blockquote>
  * <img src=logo.gif width=300 height=100>
  * </blockquote>
  * @author Mike Cohn
  * @version 1.0.0
  * @see Contractor
*/
public class Employee extends Person {
    private float salary;
    private String job;

    /** This constructor is used to create a new employee and
      * assign him an initial salary. <EM>It does not verify that
      * salary is less than the company's maximum salary.</EM>
      * You could use this method as follows:
      * <CODE><PRE>
      * Employee Emp = new Employee(35000f,"Mike","Cohn");
      * </PRE></CODE>
      * @param sal The starting salary of the new employee.
      * @param fName The employee's first name.
      * @param lName The employee's last name.
      */
    public Employee(float sal, String fName, String lName) {
        super(fName, lName);
        salary = sal;
    }


  /**
    * This method assigns the employee to the
    * specified job. This method does not verify the
    * <i>job title</i> against the list of <i>approved
    * job titles</i> created by <b>Human Resources</b>.
    * Likely job titles you may want to pass include:
    * <ul>
    * <li>Programmer
    * <li>Analyst
    * <li>QA
    * <li>Tech Writer
    * <li>Project Manager
    * <li>Database Administrator
    * <li>Database Engineer
    * </ul>
    * Reminder: All positions must be approved by the
    * <b>Manager of Human Resources</b> according to
    * the company's <CITE>Employee Hiring Guidelines.
    * </CITE>
    * @param newJob This is the new job title.
    * @see #GetJobTitle
    */
    public void AssignJob(String newJob) {
        job = newJob;
    }


  /**
    * This function returns the job title of the employee.
    * @return A string representing the job title (for
    * example, "programmer").
    * @see #AssignJob
    */
    public String GetJobTitle() {
        return job;
    }



  /**
    * This method return the highest age at which
    * an employee can remain at work. <STRONG>
    * After this age, an employee must retire and
    * move to Florida.</STRONG>
    * @return The last allowable working year before
    * mandatory retirement.
    */
    public static int GetMaxWorkingAge() {
        return 64;
    }

    /**
      * This comment will not show up in JavaDoc because
      * it is private.
      */
    private float GetMaxSalary() {
        return 200000f;
    }

  /**
    * This function changes the employees salary.
    * A salary change can occur only after the two following
    * tests have been applied:
    * <ol>
    * <li>The new salary is higher than the current salary.
    * <li>The new salary is less than the maximum salary.
    * </ol>
    * @return <B>true</B> if the salary change is approved,
    *         <B>false</B> otherwise.
    * @param newSalary The proposed new salary.
    */
    public boolean ChangeSalary(float newSalary) {
        if (newSalary < salary)
            return false;
        if (newSalary > GetMaxSalary())
            return false;
        salary = newSalary;
        return true;
    }
}


/**
  * The Contractor class is used to represent
  * contract employees. Contract employees are
  * paid by the hour.
  * @author Mike Cohn
  * @version 1.0.0
*/
class Contractor extends Employee {
    public Contractor(float sal, String fName, String lName) {
        super(sal, fName, lName);
    }
    private float hourlyRate;
  /**
    * This method can be used to retrieve the hourly rate
    * paid to the contractor.
    * @return The contractor's hourly rate, excluding
    *         exceptional circumstances such as holidays
    *         and overtime.
    */
    public float GetHourlyRate() {
        return hourlyRate;
    }
  /**
    * This method calculates how much is due to
    * a contractor based on how much he's worked
    * and his hourly rate.
    * @param hours The number of hours worked by the
    *        contractor during this pay period.
    * @return The amount of money due the contractor.
    */
    public float CalculatePayCheck(int hours) {
        return hours * hourlyRate;
    }

}



